@@ -41,7 +41,7 @@ from forgewiki.wiki_main import ForgeWikiApp
 @task(notifications_disabled=True)
 def import_tool(**kw):
     importer = TracWikiImporter()
-    with ImportErrorHandler(importer, kw.get('trac_url')):
+    with ImportErrorHandler(importer, kw.get('trac_url'), c.project):
         importer.import_tool(c.project, c.user, **kw)
 
 
@@ -68,13 +68,16 @@ class TracWikiImportController(BaseController):
     @require_post()
     @validate(TracWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, trac_url, mount_point, mount_label, **kw):
-        import_tool.post(
-                mount_point=mount_point,
-                mount_label=mount_label,
-                trac_url=trac_url,
-                )
-        flash('Wiki import has begun. Your new wiki will be available '
-                'when the import is complete.')
+        if TracWikiImporter().enforce_limit(c.project):
+            import_tool.post(
+                    mount_point=mount_point,
+                    mount_label=mount_label,
+                    trac_url=trac_url,
+                    )
+            flash('Wiki import has begun. Your new wiki will be available '
+                    'when the import is complete.')
+        else:
+            flash('There are too many imports pending at this time.  Please wait and try again.', 'error')
         redirect(c.project.url() + 'admin/')
 
 
